@@ -1,8 +1,11 @@
 test_that('Subsplits', {
   splits <- as.Splits(PectinateTree(letters[1:9]))
   efgh <- Subsplit(splits, tips = letters[5:8], keepAll = TRUE, unique = FALSE)
-  expect_equal(setNames(c(4, 4, 4, 3, 2, 1), 12:17),
-               TipsInSplits(efgh))
+  expect_equal(TipsInSplits(efgh),
+               setNames(c(4, 4, 4, 3, 2, 1), 12:17))
+  expect_equal(DropTip(splits, letters[c(1:4, 9)]), 
+               KeepTip(splits, letters[5:8]))
+  expect_equal(KeepTip(splits, letters[5:8]), Subsplit(splits, letters[5:8]))
   expect_equal(c('12' = TRUE, '13' = TRUE, '14' = TRUE, '15' = TRUE,
                  '16' = FALSE, '17' = TRUE), TrivialSplits(efgh))
 
@@ -24,15 +27,14 @@ test_that('Subsplits', {
                            't65' = TRUE)),
                unname(sub), ignore_attr = TRUE)
 
-
 })
 
-test_that('Bitwise logic works', {
+test_that("Bitwise logic works", {
   splits <- as.Splits(BalancedTree(8))
   splits2 <- as.Splits(PectinateTree(8))
   A <- TRUE
   B <- FALSE
-  .CSB <- function (a, b) .CompatibleSplit(packBits(as.logical(a)),
+  .CSB <- function(a, b) .CompatibleSplit(packBits(as.logical(a)),
                                            packBits(as.logical(b)),
                                            length(a))
   expect_true(.CSB(rep(0, 8), rep(0, 8)))
@@ -51,20 +53,17 @@ test_that('Bitwise logic works', {
   expect_false(.CSB(c(1, 0, 0, 0, 0, 0, 1, 1),
                     c(0, 0, 0, 0, 1, 1, 1, 1)))
 
-  expect_equal(
-    matrix(c(A, A, A, A, A,
-             A, B, A, A, A,
-             A, A, A, A, A,
-             A, A, A, B, A,
-             A, A, A, A, A), byrow = TRUE, 5, 5,
-           dimnames = list(11:15, 11:15)),
-    CompatibleSplits(splits, splits2))
+  expectation <- matrix(TRUE, 5, 5,
+                        dimnames = list(names(splits), names(splits2)))
+  expectation["12", "12"] <- FALSE
+  expectation["14", "14"] <- FALSE
+  expect_equal(CompatibleSplits(splits, splits2), expectation)
 
   expect_true(.CompatibleSplit(as.raw(3), as.raw(7), nTip = 5))
   expect_false(.CompatibleSplit(as.raw(3), as.raw(6), nTip = 5))
 })
 
-test_that("SplitMatchProbability returns expected probabilities", {
+test_that("SplitMatchProbability() returns expected probabilities", {
   splitAB   <- as.Splits(c(rep(TRUE, 2), rep(FALSE, 7)))
   splitABC  <- as.Splits(c(rep(TRUE, 3), rep(FALSE, 6)))
   splitABI  <- as.Splits(c(rep(TRUE, 2), rep(FALSE, 6), TRUE))
@@ -123,7 +122,7 @@ test_that("SplitMatchProbability returns expected probabilities", {
                 SplitMatchProbability(splitAI, splitAB))
 
 
-  Test <- function (score, split1, split2) {
+  Test <- function(score, split1, split2) {
     expect_equal(ignore_attr = TRUE, score, SplitMatchProbability(split1, split2))
     expect_equal(ignore_attr = TRUE, score, SplitMatchProbability(split2, split1))
 
@@ -167,7 +166,7 @@ test_that("SplitMatchProbability returns expected probabilities", {
 })
 
 
-test_that('Tip labels are found', {
+test_that("Tip labels are found", {
   pt4 <- PectinateTree(4L)
   bt4 <- BalancedTree(4L)
   t1..4 <- c('t1', 't2', 't3', 't4')
